#!/bin/sh

. ./build-env.sh

cd linux/

VERSION=`cat Makefile | grep -E '^VERSION.=' | cut -d "=" -f 2- | tr -d " \t\n\r"`
PATCHLEVEL=`cat Makefile | grep PATCHLEVEL.= | cut -d "=" -f 2- | tr -d " \t\n\r"`
SUBVERSION=`cat Makefile | grep SUBLEVEL.= | cut -d "=" -f 2- | tr -d " \t\n\r"`

export ARCH=arm64
export KBUILD_DEBARCH=arm64
export K_IMAGE=Image
export KBUILD_IMAGE=${K_IMAGE}
if [ "X${BSP_ARCH}" = "Xarmhf" ]; then
  export ARCH=arm
  export CROSS_COMPILE=arm-linux-gnueabihf-
  export KBUILD_DEBARCH=armhf

elif [ "X${BSP_ARCH}" = "Xamd64" ]; then
  export ARCH=x86
  export CROSS_COMPILE=x86_64-linux-gnu-
  export KBUILD_DEBARCH=amd64
  export KBUILD_IMAGE=bzImage
  export K_IMAGE=bzImage
  export KBUILD_IMAGE=arch/${ARCH}/boot/${K_IMAGE}

elif [ "X${BSP_ARCH}" = "Xi686" ]; then
  export ARCH=x86
  export CROSS_COMPILE=i686-linux-gnu-
  export KBUILD_DEBARCH=i686
  export KBUILD_IMAGE=bzImage
  export K_IMAGE=bzImage
  export KBUILD_IMAGE=arch/${ARCH}/boot/${K_IMAGE}
fi

export LOCALVERSION="+${BSP_MODEL}"
export KDEB_PKGVERSION="${VERSION}.${PATCHLEVEL}.${SUBVERSION}-20190527-${BSP_MODEL}"

KDEB_PKG_TASK=deb-pkg
if grep -q bindeb-pkg scripts/package/Makefile ; then
  KDEB_PKG_TASK=bindeb-pkg
fi

echo "Building ${KDEB_PKGVERSION}..."


if [ ! -e .builddate ]; then
  LANG=C date -u > .builddate
fi

BUILDVERSION=1
BUILDTIMESTAMP=`cat .builddate`
export KBUILD_BUILD_TIMESTAMP=${BUILDTIMESTAMP}
export KBUILD_BUILD_VERSION=${BUILDVERSION}


kmake() {
  echo ""
  echo "make $*"

  #KBUILD_IMAGE="Image"
    make $* KDEB_PKGVERSION="${KDEB_PKGVERSION}" LOCALVERSION="${LOCALVERSION}" ARCH=${ARCH} CROSS_COMPILE=${CROSS_COMPILE} \
  KBUILD_BUILD_TIMESTAMP="${KBUILD_BUILD_TIMESTAMP}" KBUILD_BUILD_VERSION=${KBUILD_BUILD_VERSION} \
  KBUILD_DEBARCH=${KBUILD_DEBARCH} \
  DEBFULLNAME="SCP" \
  DEBEMAIL="scsupport@detc.local"
}

kmake -j4 Image modules
kmake dtbs

kmake headers_check 
kmake scripts

#kmake -j1 deb-pkg 
kmake -j1 bindeb-pkg

cd ..

echo linux-image-${KDEB_PKGVERSION}-${KBUILD_DEBARCH}.zip
zip linux-image-${KDEB_PKGVERSION}-${KBUILD_DEBARCH}.zip install-linux.sh install-dtb.sh install-image.sh install-uinitrd.sh linux-*_${KDEB_PKGVERSION}_*.deb

