#!/bin/sh
. ./build-env.sh

export ARCH=arm64
if [ "X${BSP_ARCH}" = "Xarmhf" ]; then
  export ARCH=arm
  export CROSS_COMPILE=arm-linux-gnueabihf-

elif [ "X${BSP_ARCH}" = "Xamd64" ]; then
  export ARCH=x86
  export CROSS_COMPILE=x86_64-linux-gnu-

elif [ "X${BSP_ARCH}" = "Xi686" ]; then
  export ARCH=x86
  export CROSS_COMPILE=i686-linux-gnu-
fi

export LOCALVERSION="+${BSP_MODEL}"

ldcfg=4.1x-${BSP_MODEL}.config
lxcfg=.config

cd linux

VERSION=`cat Makefile | grep -E '^VERSION.=' | cut -d "=" -f 2- | tr -d " \t\n\r"`
PATCHLEVEL=`cat Makefile | grep PATCHLEVEL.= | cut -d "=" -f 2- | tr -d " \t\n\r"`
SUBVERSION=`cat Makefile | grep SUBLEVEL.= | cut -d "=" -f 2- | tr -d " \t\n\r"`

ldcfg=${VERSION}.${PATCHLEVEL}-${BSP_MODEL}.config

echo "Configuring ${VERSION}.${PATCHLEVEL}.${SUBVERSION}..."

make LOCALVERSION="${LOCALVERSION}" ARCH=${ARCH} CROSS_COMPILE=${CROSS_COMPILE} defconfig

if [ ! -e config-0 ]; then
  cp -p .config config-0
fi

if [ -e arch/arm/configs/${BSP_CONFIG}_defconfig ]; then
  make LOCALVERSION="${LOCALVERSION}" ARCH=${ARCH} CROSS_COMPILE=${CROSS_COMPILE} ${BSP_CONFIG}_defconfig

  cp -p .config $ldcfg
fi

lxcfg=.config
cp -p $ldcfg $lxcfg

sed -i 's|^CONFIG_LOCALVERSION_AUTO=.*|# CONFIG_LOCALVERSION_AUTO is not set|g' $lxcfg
sed -i 's|^CONFIG_DEFAULT_HOSTNAME=.*|CONFIG_DEFAULT_HOSTNAME="(none)"|g' $lxcfg

sed -i 's|^CONFIG_DEBUG_INFO=y|# CONFIG_DEBUG_INFO is not set|g' $lxcfg

sed -i 's|^CONFIG_STMMAC_ETH=m|CONFIG_STMMAC_ETH=y|g' $lxcfg
sed -i 's|^CONFIG_STMMAC_PLATFORM=m|CONFIG_STMMAC_PLATFORM=y|g' $lxcfg
sed -i 's|^CONFIG_DWMAC_GENERIC=m|CONFIG_DWMAC_GENERIC=y|g' $lxcfg
sed -i 's|^CONFIG_DWMAC_IPQ806X=m|CONFIG_DWMAC_IPQ806X=y|g' $lxcfg
sed -i 's|^CONFIG_DWMAC_MESON=m|CONFIG_DWMAC_MESON=y|g' $lxcfg
sed -i 's|^CONFIG_DWMAC_ROCKCHIP=m|CONFIG_DWMAC_ROCKCHIP=y|g' $lxcfg
sed -i 's|^CONFIG_DWMAC_SUNXI=m|CONFIG_DWMAC_SUNXI=y|g' $lxcfg

make LOCALVERSION="${LOCALVERSION}" ARCH=${ARCH} CROSS_COMPILE=${CROSS_COMPILE} oldconfig

cd ..

echo OK
